diff --git a/lmxproxy/src/ZB.MOM.WW.LmxProxy.Host/Health/DetailedHealthCheckService.cs b/lmxproxy/src/ZB.MOM.WW.LmxProxy.Host/Health/DetailedHealthCheckService.cs
index d177b24..36eb342 100644
--- a/lmxproxy/src/ZB.MOM.WW.LmxProxy.Host/Health/DetailedHealthCheckService.cs
+++ b/lmxproxy/src/ZB.MOM.WW.LmxProxy.Host/Health/DetailedHealthCheckService.cs
@@ -20,7 +20,7 @@ namespace ZB.MOM.WW.LmxProxy.Host.Health
public DetailedHealthCheckService(
IScadaClient scadaClient,
- string testTagAddress = "DevAppEngine.Scheduler.ScanTime")
+ string testTagAddress = "DevPlatform.Scheduler.ScanTime")
{
_scadaClient = scadaClient;
_testTagAddress = testTagAddress;
diff --git a/lmxproxy/src/ZB.MOM.WW.LmxProxy.Host/appsettings.json b/lmxproxy/src/ZB.MOM.WW.LmxProxy.Host/appsettings.json
index 2eff7e5..267943a 100644
--- a/lmxproxy/src/ZB.MOM.WW.LmxProxy.Host/appsettings.json
+++ b/lmxproxy/src/ZB.MOM.WW.LmxProxy.Host/appsettings.json
@@ -33,7 +33,7 @@
},
"HealthCheck": {
- "TestTagAddress": "DevAppEngine.Scheduler.ScanTime",
+ "TestTagAddress": "DevPlatform.Scheduler.ScanTime",
"ProbeTimeoutMs": 5000,
"MaxConsecutiveTransportFailures": 3,
"DegradedProbeIntervalMs": 30000
diff --git a/lmxproxy/src/ZB.MOM.WW.LmxProxy.Host/Configuration/LmxProxyConfiguration.cs b/lmxproxy/src/ZB.MOM.WW.LmxProxy.Host/Configuration/LmxProxyConfiguration.cs
index f74a2e1..71b7f09 100644
--- a/lmxproxy/src/ZB.MOM.WW.LmxProxy.Host/Configuration/LmxProxyConfiguration.cs
+++ b/lmxproxy/src/ZB.MOM.WW.LmxProxy.Host/Configuration/LmxProxyConfiguration.cs
@@ -31,8 +31,8 @@ namespace ZB.MOM.WW.LmxProxy.Host.Configuration
/// Health check / probe configuration.
public class HealthCheckConfiguration
{
- /// Tag address to probe for connection liveness. Default: DevAppEngine.Scheduler.ScanTime.
- public string TestTagAddress { get; set; } = "DevAppEngine.Scheduler.ScanTime";
+ /// Tag address to probe for connection liveness. Default: DevPlatform.Scheduler.ScanTime.
+ public string TestTagAddress { get; set; } = "DevPlatform.Scheduler.ScanTime";
/// Probe timeout in milliseconds. Default: 5000.
public int ProbeTimeoutMs { get; set; } = 5000;